from setuptools import setup

setup(name='test_gaussian_binomial_Udacity_project',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['test_gaussian_binomial_Udacity_project'],
      author = 'felixquinihildebet',
      zip_safe=False)
